# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******
from .VmomiSupport import CreateDataType, CreateManagedType
from .VmomiSupport import CreateEnumType
from .VmomiSupport import AddVersion, AddVersionParent
from .VmomiSupport import AddBreakingChangesInfo
from .VmomiSupport import F_LINK, F_LINKABLE
from .VmomiSupport import F_OPTIONAL, F_SECRET
from .VmomiSupport import newestVersions, ltsVersions
from .VmomiSupport import dottedVersions, oldestVersions

AddVersion("vim.version.v8_0_2_0", "vim25", "8.0.2.0", 0, "vim25")
AddVersion("vmodl.query.version.version4", "", "", 0, "vim25")
AddVersion("vmodl.query.version.version3", "", "", 0, "vim25")
AddVersion("vmodl.query.version.version2", "", "", 0, "vim25")
AddVersion("vmodl.query.version.version1", "", "", 0, "vim25")
AddVersion("vim.version.version8", "vim25", "5.1", 0, "vim25")
AddVersion("vim.version.version9", "vim25", "5.5", 0, "vim25")
AddVersion("vim.version.version6", "vim25", "4.1", 0, "vim25")
AddVersion("vim.version.version7", "vim25", "5.0", 0, "vim25")
AddVersion("vim.version.version1", "vim2", "2.0", 0, "vim25")
AddVersion("vim.version.v7_0_1_1", "vim25", "7.0.1.1", 0, "vim25")
AddVersion("vim.version.version4", "vim25", "2.5u2server", 0, "vim25")
AddVersion("vim.version.version5", "vim25", "4.0", 0, "vim25")
AddVersion("vim.version.version2", "vim25", "2.5", 0, "vim25")
AddVersion("vim.version.version3", "vim25", "2.5u2", 0, "vim25")
AddVersion("vslm.version.version1", "vslm", "1.0", 0, "vslm")
AddVersion("vslm.version.v7_0_1_0", "vslm", "7.0.1.0", 0, "vslm")
AddVersion("vmodl.version.version0", "", "", 0, "vim25")
AddVersion("vmodl.version.version1", "", "", 0, "vim25")
AddVersion("vmodl.version.version2", "", "", 0, "vim25")
AddVersion("vim.version.v6_9_1", "vim25", "6.9.1", 0, "vim25")
AddVersion("vim.version.v8_0_1_0", "vim25", "8.0.1.0", 0, "vim25")
AddVersion("vim.version.v7_0_0_2", "vim25", "7.0.0.2", 0, "vim25")
AddVersion("vim.version.v6_8_7", "vim25", "6.8.7", 0, "vim25")
AddVersion("vmodl.reflect.version.version1", "reflect", "1.0", 0, "reflect")
AddVersion("vmodl.reflect.version.version2", "reflect", "2.0", 0, "reflect")
AddVersion("vim.version.v8_0_0_0", "vim25", "8.0.0.0", 0, "vim25")
AddVersion("vim.version.v8_0_0_1", "vim25", "8.0.0.1", 0, "vim25")
AddVersion("vim.version.v8_0_0_2", "vim25", "8.0.0.2", 0, "vim25")
AddVersion("vim.version.v7_0_3_1", "vim25", "7.0.3.1", 0, "vim25")
AddVersion("vim.version.v7_0_3_2", "vim25", "7.0.3.2", 0, "vim25")
AddVersion("vslm.version.version15", "vslm", "6.7.3", 0, "vslm")
AddVersion("vslm.version.version14", "vslm", "6.7.2", 0, "vslm")
AddVersion("vim.version.v7_0_3_0", "vim25", "7.0.3.0", 0, "vim25")
AddVersion("vim.version.version13", "vim25", "6.7.1", 0, "vim25")
AddVersion("vim.version.version14", "vim25", "6.7.2", 0, "vim25")
AddVersion("vim.version.version15", "vim25", "6.7.3", 0, "vim25")
AddVersion("vslm.version.v7_0", "vslm", "7.0.0.0", 0, "vslm")
AddVersion("vim.version.version10", "vim25", "6.0", 0, "vim25")
AddVersion("vim.version.version11", "vim25", "6.5", 0, "vim25")
AddVersion("vim.version.version12", "vim25", "6.7", 0, "vim25")
AddVersion("vim.version.v7_0_2_0", "vim25", "7.0.2.0", 0, "vim25")
AddVersion("vim.version.v7_0_2_1", "vim25", "7.0.2.1", 0, "vim25")
AddVersion("vim.version.v7_0_1_0", "vim25", "7.0.1.0", 0, "vim25")
AddVersion("vslm.version.v7_0_2_0", "vslm", "7.0.2.0", 0, "vslm")
AddVersion("vim.version.v7_0", "vim25", "7.0.0.0", 0, "vim25")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_2_0")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version8")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version9")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version6")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version7")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version4")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version5")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version3")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_1_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_0_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_0_2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version13")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version14")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version15")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version10")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version11")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version12")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0")
AddVersionParent("vmodl.query.version.version4", "vmodl.query.version.version4")
AddVersionParent("vmodl.query.version.version4", "vmodl.query.version.version3")
AddVersionParent("vmodl.query.version.version4", "vmodl.query.version.version2")
AddVersionParent("vmodl.query.version.version4", "vmodl.query.version.version1")
AddVersionParent("vmodl.query.version.version4", "vmodl.version.version0")
AddVersionParent("vmodl.query.version.version4", "vmodl.version.version1")
AddVersionParent("vmodl.query.version.version4", "vmodl.version.version2")
AddVersionParent("vmodl.query.version.version3", "vmodl.query.version.version3")
AddVersionParent("vmodl.query.version.version3", "vmodl.query.version.version2")
AddVersionParent("vmodl.query.version.version3", "vmodl.query.version.version1")
AddVersionParent("vmodl.query.version.version3", "vmodl.version.version0")
AddVersionParent("vmodl.query.version.version3", "vmodl.version.version1")
AddVersionParent("vmodl.query.version.version2", "vmodl.query.version.version2")
AddVersionParent("vmodl.query.version.version2", "vmodl.query.version.version1")
AddVersionParent("vmodl.query.version.version2", "vmodl.version.version0")
AddVersionParent("vmodl.query.version.version2", "vmodl.version.version1")
AddVersionParent("vmodl.query.version.version1", "vmodl.query.version.version1")
AddVersionParent("vmodl.query.version.version1", "vmodl.version.version0")
AddVersionParent("vim.version.version8", "vmodl.query.version.version4")
AddVersionParent("vim.version.version8", "vmodl.query.version.version3")
AddVersionParent("vim.version.version8", "vmodl.query.version.version2")
AddVersionParent("vim.version.version8", "vmodl.query.version.version1")
AddVersionParent("vim.version.version8", "vim.version.version8")
AddVersionParent("vim.version.version8", "vim.version.version6")
AddVersionParent("vim.version.version8", "vim.version.version7")
AddVersionParent("vim.version.version8", "vim.version.version1")
AddVersionParent("vim.version.version8", "vim.version.version4")
AddVersionParent("vim.version.version8", "vim.version.version5")
AddVersionParent("vim.version.version8", "vim.version.version2")
AddVersionParent("vim.version.version8", "vim.version.version3")
AddVersionParent("vim.version.version8", "vmodl.version.version0")
AddVersionParent("vim.version.version8", "vmodl.version.version1")
AddVersionParent("vim.version.version8", "vmodl.version.version2")
AddVersionParent("vim.version.version8", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version9", "vmodl.query.version.version4")
AddVersionParent("vim.version.version9", "vmodl.query.version.version3")
AddVersionParent("vim.version.version9", "vmodl.query.version.version2")
AddVersionParent("vim.version.version9", "vmodl.query.version.version1")
AddVersionParent("vim.version.version9", "vim.version.version8")
AddVersionParent("vim.version.version9", "vim.version.version9")
AddVersionParent("vim.version.version9", "vim.version.version6")
AddVersionParent("vim.version.version9", "vim.version.version7")
AddVersionParent("vim.version.version9", "vim.version.version1")
AddVersionParent("vim.version.version9", "vim.version.version4")
AddVersionParent("vim.version.version9", "vim.version.version5")
AddVersionParent("vim.version.version9", "vim.version.version2")
AddVersionParent("vim.version.version9", "vim.version.version3")
AddVersionParent("vim.version.version9", "vmodl.version.version0")
AddVersionParent("vim.version.version9", "vmodl.version.version1")
AddVersionParent("vim.version.version9", "vmodl.version.version2")
AddVersionParent("vim.version.version9", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version6", "vmodl.query.version.version3")
AddVersionParent("vim.version.version6", "vmodl.query.version.version2")
AddVersionParent("vim.version.version6", "vmodl.query.version.version1")
AddVersionParent("vim.version.version6", "vim.version.version6")
AddVersionParent("vim.version.version6", "vim.version.version1")
AddVersionParent("vim.version.version6", "vim.version.version4")
AddVersionParent("vim.version.version6", "vim.version.version5")
AddVersionParent("vim.version.version6", "vim.version.version2")
AddVersionParent("vim.version.version6", "vim.version.version3")
AddVersionParent("vim.version.version6", "vmodl.version.version0")
AddVersionParent("vim.version.version6", "vmodl.version.version1")
AddVersionParent("vim.version.version7", "vmodl.query.version.version4")
AddVersionParent("vim.version.version7", "vmodl.query.version.version3")
AddVersionParent("vim.version.version7", "vmodl.query.version.version2")
AddVersionParent("vim.version.version7", "vmodl.query.version.version1")
AddVersionParent("vim.version.version7", "vim.version.version6")
AddVersionParent("vim.version.version7", "vim.version.version7")
AddVersionParent("vim.version.version7", "vim.version.version1")
AddVersionParent("vim.version.version7", "vim.version.version4")
AddVersionParent("vim.version.version7", "vim.version.version5")
AddVersionParent("vim.version.version7", "vim.version.version2")
AddVersionParent("vim.version.version7", "vim.version.version3")
AddVersionParent("vim.version.version7", "vmodl.version.version0")
AddVersionParent("vim.version.version7", "vmodl.version.version1")
AddVersionParent("vim.version.version7", "vmodl.version.version2")
AddVersionParent("vim.version.version7", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version1", "vmodl.query.version.version1")
AddVersionParent("vim.version.version1", "vim.version.version1")
AddVersionParent("vim.version.version1", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version8")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version9")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version6")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version7")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version1")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version4")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version5")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version2")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version3")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version13")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version14")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version15")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version10")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version11")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version12")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v7_0")
AddVersionParent("vim.version.version4", "vmodl.query.version.version1")
AddVersionParent("vim.version.version4", "vim.version.version1")
AddVersionParent("vim.version.version4", "vim.version.version4")
AddVersionParent("vim.version.version4", "vim.version.version2")
AddVersionParent("vim.version.version4", "vim.version.version3")
AddVersionParent("vim.version.version4", "vmodl.version.version0")
AddVersionParent("vim.version.version5", "vmodl.query.version.version2")
AddVersionParent("vim.version.version5", "vmodl.query.version.version1")
AddVersionParent("vim.version.version5", "vim.version.version1")
AddVersionParent("vim.version.version5", "vim.version.version4")
AddVersionParent("vim.version.version5", "vim.version.version5")
AddVersionParent("vim.version.version5", "vim.version.version2")
AddVersionParent("vim.version.version5", "vim.version.version3")
AddVersionParent("vim.version.version5", "vmodl.version.version0")
AddVersionParent("vim.version.version5", "vmodl.version.version1")
AddVersionParent("vim.version.version2", "vmodl.query.version.version1")
AddVersionParent("vim.version.version2", "vim.version.version1")
AddVersionParent("vim.version.version2", "vim.version.version2")
AddVersionParent("vim.version.version2", "vmodl.version.version0")
AddVersionParent("vim.version.version3", "vmodl.query.version.version1")
AddVersionParent("vim.version.version3", "vim.version.version1")
AddVersionParent("vim.version.version3", "vim.version.version2")
AddVersionParent("vim.version.version3", "vim.version.version3")
AddVersionParent("vim.version.version3", "vmodl.version.version0")
AddVersionParent("vslm.version.version1", "vmodl.query.version.version4")
AddVersionParent("vslm.version.version1", "vmodl.query.version.version3")
AddVersionParent("vslm.version.version1", "vmodl.query.version.version2")
AddVersionParent("vslm.version.version1", "vmodl.query.version.version1")
AddVersionParent("vslm.version.version1", "vim.version.version8")
AddVersionParent("vslm.version.version1", "vim.version.version9")
AddVersionParent("vslm.version.version1", "vim.version.version6")
AddVersionParent("vslm.version.version1", "vim.version.version7")
AddVersionParent("vslm.version.version1", "vim.version.version1")
AddVersionParent("vslm.version.version1", "vim.version.version4")
AddVersionParent("vslm.version.version1", "vim.version.version5")
AddVersionParent("vslm.version.version1", "vim.version.version2")
AddVersionParent("vslm.version.version1", "vim.version.version3")
AddVersionParent("vslm.version.version1", "vslm.version.version1")
AddVersionParent("vslm.version.version1", "vmodl.version.version0")
AddVersionParent("vslm.version.version1", "vmodl.version.version1")
AddVersionParent("vslm.version.version1", "vmodl.version.version2")
AddVersionParent("vslm.version.version1", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.version1", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.version1", "vim.version.version10")
AddVersionParent("vslm.version.version1", "vim.version.version11")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.query.version.version4")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.query.version.version3")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.query.version.version2")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.query.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version8")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version9")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version6")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version7")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version4")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version5")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version2")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version3")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.v7_0_1_0")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.version.version0")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.version.version2")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v6_9_1")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v7_0_0_2")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v6_8_7")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.version15")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.version14")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version13")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version14")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version15")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.v7_0")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version10")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version11")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version12")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v7_0_1_0")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v7_0")
AddVersionParent("vmodl.version.version0", "vmodl.version.version0")
AddVersionParent("vmodl.version.version1", "vmodl.version.version0")
AddVersionParent("vmodl.version.version1", "vmodl.version.version1")
AddVersionParent("vmodl.version.version2", "vmodl.version.version0")
AddVersionParent("vmodl.version.version2", "vmodl.version.version1")
AddVersionParent("vmodl.version.version2", "vmodl.version.version2")
AddVersionParent("vim.version.v6_9_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v6_9_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v6_9_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v6_9_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v6_9_1", "vim.version.version8")
AddVersionParent("vim.version.v6_9_1", "vim.version.version9")
AddVersionParent("vim.version.v6_9_1", "vim.version.version6")
AddVersionParent("vim.version.v6_9_1", "vim.version.version7")
AddVersionParent("vim.version.v6_9_1", "vim.version.version1")
AddVersionParent("vim.version.v6_9_1", "vim.version.version4")
AddVersionParent("vim.version.v6_9_1", "vim.version.version5")
AddVersionParent("vim.version.v6_9_1", "vim.version.version2")
AddVersionParent("vim.version.v6_9_1", "vim.version.version3")
AddVersionParent("vim.version.v6_9_1", "vmodl.version.version0")
AddVersionParent("vim.version.v6_9_1", "vmodl.version.version1")
AddVersionParent("vim.version.v6_9_1", "vmodl.version.version2")
AddVersionParent("vim.version.v6_9_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v6_9_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v6_9_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v6_9_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v6_9_1", "vim.version.version13")
AddVersionParent("vim.version.v6_9_1", "vim.version.version14")
AddVersionParent("vim.version.v6_9_1", "vim.version.version15")
AddVersionParent("vim.version.v6_9_1", "vim.version.version10")
AddVersionParent("vim.version.v6_9_1", "vim.version.version11")
AddVersionParent("vim.version.v6_9_1", "vim.version.version12")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version8")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version9")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version6")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version7")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version4")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version5")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version3")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v8_0_1_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v8_0_0_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v8_0_0_2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version13")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version14")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version15")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version10")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version11")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version12")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version8")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version9")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version6")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version7")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version1")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version4")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version5")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version2")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version3")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version13")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version14")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version15")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version10")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version11")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version12")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.v7_0")
AddVersionParent("vim.version.v6_8_7", "vmodl.query.version.version4")
AddVersionParent("vim.version.v6_8_7", "vmodl.query.version.version3")
AddVersionParent("vim.version.v6_8_7", "vmodl.query.version.version2")
AddVersionParent("vim.version.v6_8_7", "vmodl.query.version.version1")
AddVersionParent("vim.version.v6_8_7", "vim.version.version8")
AddVersionParent("vim.version.v6_8_7", "vim.version.version9")
AddVersionParent("vim.version.v6_8_7", "vim.version.version6")
AddVersionParent("vim.version.v6_8_7", "vim.version.version7")
AddVersionParent("vim.version.v6_8_7", "vim.version.version1")
AddVersionParent("vim.version.v6_8_7", "vim.version.version4")
AddVersionParent("vim.version.v6_8_7", "vim.version.version5")
AddVersionParent("vim.version.v6_8_7", "vim.version.version2")
AddVersionParent("vim.version.v6_8_7", "vim.version.version3")
AddVersionParent("vim.version.v6_8_7", "vmodl.version.version0")
AddVersionParent("vim.version.v6_8_7", "vmodl.version.version1")
AddVersionParent("vim.version.v6_8_7", "vmodl.version.version2")
AddVersionParent("vim.version.v6_8_7", "vim.version.v6_8_7")
AddVersionParent("vim.version.v6_8_7", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v6_8_7", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v6_8_7", "vim.version.version13")
AddVersionParent("vim.version.v6_8_7", "vim.version.version14")
AddVersionParent("vim.version.v6_8_7", "vim.version.version15")
AddVersionParent("vim.version.v6_8_7", "vim.version.version10")
AddVersionParent("vim.version.v6_8_7", "vim.version.version11")
AddVersionParent("vim.version.v6_8_7", "vim.version.version12")
AddVersionParent("vmodl.reflect.version.version1", "vmodl.version.version0")
AddVersionParent("vmodl.reflect.version.version1", "vmodl.version.version1")
AddVersionParent("vmodl.reflect.version.version1", "vmodl.version.version2")
AddVersionParent("vmodl.reflect.version.version1", "vmodl.reflect.version.version1")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.version.version0")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.version.version1")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.version.version2")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.reflect.version.version1")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version8")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version9")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version6")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version7")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version4")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version5")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version3")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version13")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version14")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version15")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version10")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version11")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version12")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version8")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version9")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version6")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version7")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version4")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version5")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version3")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v8_0_0_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version13")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version14")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version15")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version10")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version11")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version12")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version8")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version9")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version6")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version7")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version4")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version5")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version3")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v8_0_0_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v8_0_0_2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version13")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version14")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version15")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version10")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version11")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version12")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version8")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version9")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version6")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version7")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version4")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version5")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version2")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version3")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version13")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version14")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version15")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version10")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version11")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version12")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version8")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version9")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version6")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version7")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version4")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version5")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version3")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version13")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version14")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version15")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version10")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version11")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version12")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0")
AddVersionParent("vslm.version.version15", "vmodl.query.version.version4")
AddVersionParent("vslm.version.version15", "vmodl.query.version.version3")
AddVersionParent("vslm.version.version15", "vmodl.query.version.version2")
AddVersionParent("vslm.version.version15", "vmodl.query.version.version1")
AddVersionParent("vslm.version.version15", "vim.version.version8")
AddVersionParent("vslm.version.version15", "vim.version.version9")
AddVersionParent("vslm.version.version15", "vim.version.version6")
AddVersionParent("vslm.version.version15", "vim.version.version7")
AddVersionParent("vslm.version.version15", "vim.version.version1")
AddVersionParent("vslm.version.version15", "vim.version.version4")
AddVersionParent("vslm.version.version15", "vim.version.version5")
AddVersionParent("vslm.version.version15", "vim.version.version2")
AddVersionParent("vslm.version.version15", "vim.version.version3")
AddVersionParent("vslm.version.version15", "vslm.version.version1")
AddVersionParent("vslm.version.version15", "vmodl.version.version0")
AddVersionParent("vslm.version.version15", "vmodl.version.version1")
AddVersionParent("vslm.version.version15", "vmodl.version.version2")
AddVersionParent("vslm.version.version15", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.version15", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.version15", "vslm.version.version15")
AddVersionParent("vslm.version.version15", "vslm.version.version14")
AddVersionParent("vslm.version.version15", "vim.version.version13")
AddVersionParent("vslm.version.version15", "vim.version.version14")
AddVersionParent("vslm.version.version15", "vim.version.version15")
AddVersionParent("vslm.version.version15", "vim.version.version10")
AddVersionParent("vslm.version.version15", "vim.version.version11")
AddVersionParent("vslm.version.version15", "vim.version.version12")
AddVersionParent("vslm.version.version14", "vmodl.query.version.version4")
AddVersionParent("vslm.version.version14", "vmodl.query.version.version3")
AddVersionParent("vslm.version.version14", "vmodl.query.version.version2")
AddVersionParent("vslm.version.version14", "vmodl.query.version.version1")
AddVersionParent("vslm.version.version14", "vim.version.version8")
AddVersionParent("vslm.version.version14", "vim.version.version9")
AddVersionParent("vslm.version.version14", "vim.version.version6")
AddVersionParent("vslm.version.version14", "vim.version.version7")
AddVersionParent("vslm.version.version14", "vim.version.version1")
AddVersionParent("vslm.version.version14", "vim.version.version4")
AddVersionParent("vslm.version.version14", "vim.version.version5")
AddVersionParent("vslm.version.version14", "vim.version.version2")
AddVersionParent("vslm.version.version14", "vim.version.version3")
AddVersionParent("vslm.version.version14", "vslm.version.version1")
AddVersionParent("vslm.version.version14", "vmodl.version.version0")
AddVersionParent("vslm.version.version14", "vmodl.version.version1")
AddVersionParent("vslm.version.version14", "vmodl.version.version2")
AddVersionParent("vslm.version.version14", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.version14", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.version14", "vslm.version.version14")
AddVersionParent("vslm.version.version14", "vim.version.version13")
AddVersionParent("vslm.version.version14", "vim.version.version14")
AddVersionParent("vslm.version.version14", "vim.version.version10")
AddVersionParent("vslm.version.version14", "vim.version.version11")
AddVersionParent("vslm.version.version14", "vim.version.version12")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version8")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version9")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version6")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version7")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version4")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version5")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version2")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version3")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version13")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version14")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version15")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version10")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version11")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version12")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0")
AddVersionParent("vim.version.version13", "vmodl.query.version.version4")
AddVersionParent("vim.version.version13", "vmodl.query.version.version3")
AddVersionParent("vim.version.version13", "vmodl.query.version.version2")
AddVersionParent("vim.version.version13", "vmodl.query.version.version1")
AddVersionParent("vim.version.version13", "vim.version.version8")
AddVersionParent("vim.version.version13", "vim.version.version9")
AddVersionParent("vim.version.version13", "vim.version.version6")
AddVersionParent("vim.version.version13", "vim.version.version7")
AddVersionParent("vim.version.version13", "vim.version.version1")
AddVersionParent("vim.version.version13", "vim.version.version4")
AddVersionParent("vim.version.version13", "vim.version.version5")
AddVersionParent("vim.version.version13", "vim.version.version2")
AddVersionParent("vim.version.version13", "vim.version.version3")
AddVersionParent("vim.version.version13", "vmodl.version.version0")
AddVersionParent("vim.version.version13", "vmodl.version.version1")
AddVersionParent("vim.version.version13", "vmodl.version.version2")
AddVersionParent("vim.version.version13", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version13", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version13", "vim.version.version13")
AddVersionParent("vim.version.version13", "vim.version.version10")
AddVersionParent("vim.version.version13", "vim.version.version11")
AddVersionParent("vim.version.version13", "vim.version.version12")
AddVersionParent("vim.version.version14", "vmodl.query.version.version4")
AddVersionParent("vim.version.version14", "vmodl.query.version.version3")
AddVersionParent("vim.version.version14", "vmodl.query.version.version2")
AddVersionParent("vim.version.version14", "vmodl.query.version.version1")
AddVersionParent("vim.version.version14", "vim.version.version8")
AddVersionParent("vim.version.version14", "vim.version.version9")
AddVersionParent("vim.version.version14", "vim.version.version6")
AddVersionParent("vim.version.version14", "vim.version.version7")
AddVersionParent("vim.version.version14", "vim.version.version1")
AddVersionParent("vim.version.version14", "vim.version.version4")
AddVersionParent("vim.version.version14", "vim.version.version5")
AddVersionParent("vim.version.version14", "vim.version.version2")
AddVersionParent("vim.version.version14", "vim.version.version3")
AddVersionParent("vim.version.version14", "vmodl.version.version0")
AddVersionParent("vim.version.version14", "vmodl.version.version1")
AddVersionParent("vim.version.version14", "vmodl.version.version2")
AddVersionParent("vim.version.version14", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version14", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version14", "vim.version.version13")
AddVersionParent("vim.version.version14", "vim.version.version14")
AddVersionParent("vim.version.version14", "vim.version.version10")
AddVersionParent("vim.version.version14", "vim.version.version11")
AddVersionParent("vim.version.version14", "vim.version.version12")
AddVersionParent("vim.version.version15", "vmodl.query.version.version4")
AddVersionParent("vim.version.version15", "vmodl.query.version.version3")
AddVersionParent("vim.version.version15", "vmodl.query.version.version2")
AddVersionParent("vim.version.version15", "vmodl.query.version.version1")
AddVersionParent("vim.version.version15", "vim.version.version8")
AddVersionParent("vim.version.version15", "vim.version.version9")
AddVersionParent("vim.version.version15", "vim.version.version6")
AddVersionParent("vim.version.version15", "vim.version.version7")
AddVersionParent("vim.version.version15", "vim.version.version1")
AddVersionParent("vim.version.version15", "vim.version.version4")
AddVersionParent("vim.version.version15", "vim.version.version5")
AddVersionParent("vim.version.version15", "vim.version.version2")
AddVersionParent("vim.version.version15", "vim.version.version3")
AddVersionParent("vim.version.version15", "vmodl.version.version0")
AddVersionParent("vim.version.version15", "vmodl.version.version1")
AddVersionParent("vim.version.version15", "vmodl.version.version2")
AddVersionParent("vim.version.version15", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version15", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version15", "vim.version.version13")
AddVersionParent("vim.version.version15", "vim.version.version14")
AddVersionParent("vim.version.version15", "vim.version.version15")
AddVersionParent("vim.version.version15", "vim.version.version10")
AddVersionParent("vim.version.version15", "vim.version.version11")
AddVersionParent("vim.version.version15", "vim.version.version12")
AddVersionParent("vslm.version.v7_0", "vmodl.query.version.version4")
AddVersionParent("vslm.version.v7_0", "vmodl.query.version.version3")
AddVersionParent("vslm.version.v7_0", "vmodl.query.version.version2")
AddVersionParent("vslm.version.v7_0", "vmodl.query.version.version1")
AddVersionParent("vslm.version.v7_0", "vim.version.version8")
AddVersionParent("vslm.version.v7_0", "vim.version.version9")
AddVersionParent("vslm.version.v7_0", "vim.version.version6")
AddVersionParent("vslm.version.v7_0", "vim.version.version7")
AddVersionParent("vslm.version.v7_0", "vim.version.version1")
AddVersionParent("vslm.version.v7_0", "vim.version.version4")
AddVersionParent("vslm.version.v7_0", "vim.version.version5")
AddVersionParent("vslm.version.v7_0", "vim.version.version2")
AddVersionParent("vslm.version.v7_0", "vim.version.version3")
AddVersionParent("vslm.version.v7_0", "vslm.version.version1")
AddVersionParent("vslm.version.v7_0", "vmodl.version.version0")
AddVersionParent("vslm.version.v7_0", "vmodl.version.version1")
AddVersionParent("vslm.version.v7_0", "vmodl.version.version2")
AddVersionParent("vslm.version.v7_0", "vim.version.v6_9_1")
AddVersionParent("vslm.version.v7_0", "vim.version.v6_8_7")
AddVersionParent("vslm.version.v7_0", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.v7_0", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.v7_0", "vslm.version.version15")
AddVersionParent("vslm.version.v7_0", "vslm.version.version14")
AddVersionParent("vslm.version.v7_0", "vim.version.version13")
AddVersionParent("vslm.version.v7_0", "vim.version.version14")
AddVersionParent("vslm.version.v7_0", "vim.version.version15")
AddVersionParent("vslm.version.v7_0", "vslm.version.v7_0")
AddVersionParent("vslm.version.v7_0", "vim.version.version10")
AddVersionParent("vslm.version.v7_0", "vim.version.version11")
AddVersionParent("vslm.version.v7_0", "vim.version.version12")
AddVersionParent("vslm.version.v7_0", "vim.version.v7_0")
AddVersionParent("vim.version.version10", "vmodl.query.version.version4")
AddVersionParent("vim.version.version10", "vmodl.query.version.version3")
AddVersionParent("vim.version.version10", "vmodl.query.version.version2")
AddVersionParent("vim.version.version10", "vmodl.query.version.version1")
AddVersionParent("vim.version.version10", "vim.version.version8")
AddVersionParent("vim.version.version10", "vim.version.version9")
AddVersionParent("vim.version.version10", "vim.version.version6")
AddVersionParent("vim.version.version10", "vim.version.version7")
AddVersionParent("vim.version.version10", "vim.version.version1")
AddVersionParent("vim.version.version10", "vim.version.version4")
AddVersionParent("vim.version.version10", "vim.version.version5")
AddVersionParent("vim.version.version10", "vim.version.version2")
AddVersionParent("vim.version.version10", "vim.version.version3")
AddVersionParent("vim.version.version10", "vmodl.version.version0")
AddVersionParent("vim.version.version10", "vmodl.version.version1")
AddVersionParent("vim.version.version10", "vmodl.version.version2")
AddVersionParent("vim.version.version10", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version10", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version10", "vim.version.version10")
AddVersionParent("vim.version.version11", "vmodl.query.version.version4")
AddVersionParent("vim.version.version11", "vmodl.query.version.version3")
AddVersionParent("vim.version.version11", "vmodl.query.version.version2")
AddVersionParent("vim.version.version11", "vmodl.query.version.version1")
AddVersionParent("vim.version.version11", "vim.version.version8")
AddVersionParent("vim.version.version11", "vim.version.version9")
AddVersionParent("vim.version.version11", "vim.version.version6")
AddVersionParent("vim.version.version11", "vim.version.version7")
AddVersionParent("vim.version.version11", "vim.version.version1")
AddVersionParent("vim.version.version11", "vim.version.version4")
AddVersionParent("vim.version.version11", "vim.version.version5")
AddVersionParent("vim.version.version11", "vim.version.version2")
AddVersionParent("vim.version.version11", "vim.version.version3")
AddVersionParent("vim.version.version11", "vmodl.version.version0")
AddVersionParent("vim.version.version11", "vmodl.version.version1")
AddVersionParent("vim.version.version11", "vmodl.version.version2")
AddVersionParent("vim.version.version11", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version11", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version11", "vim.version.version10")
AddVersionParent("vim.version.version11", "vim.version.version11")
AddVersionParent("vim.version.version12", "vmodl.query.version.version4")
AddVersionParent("vim.version.version12", "vmodl.query.version.version3")
AddVersionParent("vim.version.version12", "vmodl.query.version.version2")
AddVersionParent("vim.version.version12", "vmodl.query.version.version1")
AddVersionParent("vim.version.version12", "vim.version.version8")
AddVersionParent("vim.version.version12", "vim.version.version9")
AddVersionParent("vim.version.version12", "vim.version.version6")
AddVersionParent("vim.version.version12", "vim.version.version7")
AddVersionParent("vim.version.version12", "vim.version.version1")
AddVersionParent("vim.version.version12", "vim.version.version4")
AddVersionParent("vim.version.version12", "vim.version.version5")
AddVersionParent("vim.version.version12", "vim.version.version2")
AddVersionParent("vim.version.version12", "vim.version.version3")
AddVersionParent("vim.version.version12", "vmodl.version.version0")
AddVersionParent("vim.version.version12", "vmodl.version.version1")
AddVersionParent("vim.version.version12", "vmodl.version.version2")
AddVersionParent("vim.version.version12", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version12", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version12", "vim.version.version10")
AddVersionParent("vim.version.version12", "vim.version.version11")
AddVersionParent("vim.version.version12", "vim.version.version12")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version8")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version9")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version6")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version7")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version1")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version4")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version5")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version2")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version3")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version13")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version14")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version15")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version10")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version11")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version12")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version8")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version9")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version6")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version7")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version4")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version5")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version2")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version3")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version13")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version14")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version15")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version10")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version11")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version12")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version8")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version9")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version6")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version7")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version1")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version4")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version5")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version2")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version3")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version13")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version14")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version15")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version10")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version11")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version12")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v7_0")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.query.version.version4")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.query.version.version3")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.query.version.version2")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.query.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version8")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version9")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version6")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version7")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0_1_1")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version4")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version5")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version2")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version3")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.v7_0_1_0")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.version.version0")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.version.version2")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v6_9_1")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0_0_2")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v6_8_7")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.version15")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.version14")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version13")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version14")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version15")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.v7_0")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version10")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version11")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version12")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0_2_0")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0_1_0")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.v7_0_2_0")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0", "vim.version.version8")
AddVersionParent("vim.version.v7_0", "vim.version.version9")
AddVersionParent("vim.version.v7_0", "vim.version.version6")
AddVersionParent("vim.version.v7_0", "vim.version.version7")
AddVersionParent("vim.version.v7_0", "vim.version.version1")
AddVersionParent("vim.version.v7_0", "vim.version.version4")
AddVersionParent("vim.version.v7_0", "vim.version.version5")
AddVersionParent("vim.version.v7_0", "vim.version.version2")
AddVersionParent("vim.version.v7_0", "vim.version.version3")
AddVersionParent("vim.version.v7_0", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0", "vim.version.version13")
AddVersionParent("vim.version.v7_0", "vim.version.version14")
AddVersionParent("vim.version.v7_0", "vim.version.version15")
AddVersionParent("vim.version.v7_0", "vim.version.version10")
AddVersionParent("vim.version.v7_0", "vim.version.version11")
AddVersionParent("vim.version.v7_0", "vim.version.version12")
AddVersionParent("vim.version.v7_0", "vim.version.v7_0")

newestVersions.Add("vslm.version.v7_0_2_0")
ltsVersions.Add("vslm.version.v7_0_2_0")
dottedVersions.Add("vslm.version.v7_0_2_0")
oldestVersions.Add("vslm.version.version1")

CreateDataType("vslm.AboutInfo", "VslmAboutInfo", "vmodl.DynamicData", "vslm.version.version1", [("name", "string", "vslm.version.version1", 0), ("fullName", "string", "vslm.version.version1", 0), ("vendor", "string", "vslm.version.version1", 0), ("apiVersion", "string", "vslm.version.version1", 0), ("instanceUuid", "string", "vslm.version.version1", 0)])
CreateDataType("vslm.QueryDatastoreInfoResult", "VslmQueryDatastoreInfoResult", "vmodl.DynamicData", "vslm.version.version14", [("datacenter", "vim.Datacenter", "vslm.version.version14", 0), ("datastore", "vim.Datastore", "vslm.version.version14", 0)])
CreateManagedType("vslm.ServiceInstance", "VslmServiceInstance", "vmodl.ManagedObject", "vslm.version.version14", [("content", "vslm.ServiceInstanceContent", "vslm.version.version14", 0, "System.Anonymous")], [("retrieveContent", "RetrieveContent", "vslm.version.version14", (), (0, "vslm.ServiceInstanceContent", "vslm.ServiceInstanceContent"), "System.Anonymous", None)])
CreateDataType("vslm.ServiceInstanceContent", "VslmServiceInstanceContent", "vmodl.DynamicData", "vslm.version.version14", [("aboutInfo", "vslm.AboutInfo", "vslm.version.version14", 0), ("sessionManager", "vslm.auth.SessionManager", "vslm.version.version14", 0), ("vStorageObjectManager", "vslm.vso.VStorageObjectManager", "vslm.version.version14", 0), ("storageLifecycleManager", "vslm.StorageLifecycleManager", "vslm.version.version14", 0)])
CreateManagedType("vslm.StorageLifecycleManager", "VslmStorageLifecycleManager", "vmodl.ManagedObject", "vslm.version.version14", None, [("syncDatastore", "VslmSyncDatastore", "vslm.version.version14", (("datastoreUrl", "string", "vslm.version.version14", 0, None),("fullSync", "boolean", "vslm.version.version14", 0, None),("fcdId", "vim.vslm.ID", "vslm.version.version14", F_OPTIONAL, None),), (0, "void", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.SyncFault", "vslm.fault.VslmFault", ]), ("queryDatastoreInfo", "VslmQueryDatastoreInfo", "vslm.version.version14", (("datastoreUrl", "string", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vslm.QueryDatastoreInfoResult[]", "vslm.QueryDatastoreInfoResult[]"), "System.View", ["vim.fault.NotFound", "vslm.fault.VslmFault", ])])
CreateManagedType("vslm.Task", "VslmTask", "vmodl.ManagedObject", "vslm.version.version14", None, [("queryResult", "VslmQueryTaskResult", "vslm.version.version14", (), (F_OPTIONAL, "anyType", "anyType"), None, None), ("queryInfo", "VslmQueryInfo", "vslm.version.version14", (), (0, "vslm.TaskInfo", "vslm.TaskInfo"), None, None), ("cancel", "VslmCancelTask", "vslm.version.version14", (), (0, "void", "void"), None, ["vim.fault.InvalidState", ])])
CreateDataType("vslm.TaskInfo", "VslmTaskInfo", "vmodl.DynamicData", "vslm.version.version14", [("key", "string", "vslm.version.version14", 0), ("task", "vslm.Task", "vslm.version.version14", 0), ("description", "vmodl.LocalizableMessage", "vslm.version.version14", F_OPTIONAL), ("name", "vmodl.MethodName", "vslm.version.version14", F_OPTIONAL), ("descriptionId", "string", "vslm.version.version14", 0), ("entity", "vim.ManagedEntity", "vslm.version.version14", F_OPTIONAL), ("entityName", "string", "vslm.version.version14", F_OPTIONAL), ("locked", "vim.ManagedEntity[]", "vslm.version.version14", F_OPTIONAL), ("state", "vslm.TaskInfo.State", "vslm.version.version14", 0), ("cancelled", "boolean", "vslm.version.version14", 0), ("cancelable", "boolean", "vslm.version.version14", 0), ("error", "vmodl.MethodFault", "vslm.version.version14", F_OPTIONAL), ("result", "anyType", "vslm.version.version14", F_OPTIONAL), ("progress", "int", "vslm.version.version14", F_OPTIONAL), ("reason", "vslm.TaskReason", "vslm.version.version14", 0), ("queueTime", "vmodl.DateTime", "vslm.version.version14", 0), ("startTime", "vmodl.DateTime", "vslm.version.version14", F_OPTIONAL), ("completeTime", "vmodl.DateTime", "vslm.version.version14", F_OPTIONAL), ("eventChainId", "int", "vslm.version.version14", 0), ("changeTag", "string", "vslm.version.version14", F_OPTIONAL), ("parentTaskKey", "string", "vslm.version.version14", F_OPTIONAL), ("rootTaskKey", "string", "vslm.version.version14", F_OPTIONAL), ("activationId", "string", "vslm.version.version14", F_OPTIONAL)])
CreateEnumType("vslm.TaskInfo.State", "VslmTaskInfoState", "vslm.version.version14", ["queued", "running", "success", "error"])
CreateDataType("vslm.TaskReason", "VslmTaskReason", "vmodl.DynamicData", "vslm.version.version1", None)
CreateDataType("vslm.TaskReasonAlarm", "VslmTaskReasonAlarm", "vslm.TaskReason", "vslm.version.version1", [("alarmName", "string", "vslm.version.version1", 0), ("alarm", "vim.alarm.Alarm", "vslm.version.version1", 0), ("entityName", "string", "vslm.version.version1", 0), ("entity", "vim.ManagedEntity", "vslm.version.version1", 0)])
CreateDataType("vslm.TaskReasonSchedule", "VslmTaskReasonSchedule", "vslm.TaskReason", "vslm.version.version1", [("name", "string", "vslm.version.version1", 0), ("scheduledTask", "vim.scheduler.ScheduledTask", "vslm.version.version1", 0)])
CreateDataType("vslm.TaskReasonSystem", "VslmTaskReasonSystem", "vslm.TaskReason", "vslm.version.version1", None)
CreateDataType("vslm.TaskReasonUser", "VslmTaskReasonUser", "vslm.TaskReason", "vslm.version.version1", [("userName", "string", "vslm.version.version1", 0)])
CreateManagedType("vslm.auth.SessionManager", "VslmSessionManager", "vmodl.ManagedObject", "vslm.version.version14", None, [("loginByToken", "VslmLoginByToken", "vslm.version.version14", (("delegatedTokenXml", "string", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.Anonymous", ["vim.fault.InvalidLogin", ]), ("logout", "VslmLogout", "vslm.version.version14", (), (0, "void", "void"), "StoragLifecycle.View", None)])
CreateEnumType("vslm.event.VslmEvent.VslmEventType", "VslmEventType", "vslm.version.version1", ["preFcdMigrateEvent", "postFcdMigrateEvent"])
CreateEnumType("vslm.event.VslmEventInfo.State", "VslmEventVslmEventInfoState", "vslm.version.version1", ["success", "error"])
CreateDataType("vslm.fault.VslmFault", "VslmFault", "vmodl.MethodFault", "vslm.version.version14", [("msg", "string", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.DatastoreSyncStatus", "VslmDatastoreSyncStatus", "vmodl.DynamicData", "vslm.version.version14", [("datastoreURL", "string", "vslm.version.version14", 0), ("objectVClock", "long", "vslm.version.version14", 0), ("syncVClock", "long", "vslm.version.version14", 0), ("syncTime", "vmodl.DateTime", "vslm.version.version14", F_OPTIONAL), ("numberOfRetries", "int", "vslm.version.version14", F_OPTIONAL), ("error", "vmodl.MethodFault", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.VStorageObjectAssociations", "VslmVsoVStorageObjectAssociations", "vmodl.DynamicData", "vslm.version.version14", [("id", "vim.vslm.ID", "vslm.version.version14", 0), ("vmDiskAssociation", "vslm.vso.VStorageObjectAssociations.VmDiskAssociation[]", "vslm.version.version14", F_OPTIONAL), ("fault", "vmodl.MethodFault", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.VStorageObjectAssociations.VmDiskAssociation", "VslmVsoVStorageObjectAssociationsVmDiskAssociation", "vmodl.DynamicData", "vslm.version.version14", [("vmId", "string", "vslm.version.version14", 0), ("diskKey", "int", "vslm.version.version14", 0)])
CreateManagedType("vslm.vso.VStorageObjectManager", "VslmVStorageObjectManager", "vmodl.ManagedObject", "vslm.version.version14", None, [("createDisk", "VslmCreateDisk_Task", "vslm.version.version14", (("spec", "vim.vslm.CreateSpec", "vslm.version.version14", 0, None),), (0, "vslm.Task", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vslm.fault.VslmFault", ]), ("registerDisk", "VslmRegisterDisk", "vslm.version.version14", (("path", "string", "vslm.version.version14", 0, None),("name", "string", "vslm.version.version14", F_OPTIONAL, None),), (0, "vim.vslm.VStorageObject", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.AlreadyExists", "vslm.fault.SyncFault", "vslm.fault.VslmFault", ]), ("extendDisk", "VslmExtendDisk_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("newCapacityInMB", "long", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.NotFound", "vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("inflateDisk", "VslmInflateDisk_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.NotFound", "vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("renameVStorageObject", "VslmRenameVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("name", "string", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.SyncFault", "vslm.fault.VslmFault", ]), ("updateVStorageObjectPolicy", "VslmUpdateVstorageObjectPolicy_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("profile", "vim.vm.ProfileSpec[]", "vslm.version.version14", F_OPTIONAL, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("updateVStorageObjectCrypto", "VslmUpdateVstorageObjectCrypto_Task", "vslm.version.v7_0", (("id", "vim.vslm.ID", "vslm.version.v7_0", 0, None),("profile", "vim.vm.ProfileSpec[]", "vslm.version.v7_0", F_OPTIONAL, None),("disksCrypto", "vim.vslm.DiskCryptoSpec", "vslm.version.v7_0", F_OPTIONAL, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("updateVStorageInfrastructureObjectPolicy", "VslmUpdateVStorageInfrastructureObjectPolicy_Task", "vslm.version.version14", (("spec", "vim.vslm.InfrastructureObjectPolicySpec", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.InvalidState", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("retrieveVStorageInfrastructureObjectPolicy", "VslmRetrieveVStorageInfrastructureObjectPolicy", "vslm.version.version14", (("datastore", "vim.Datastore", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vim.vslm.InfrastructureObjectPolicy[]", "vim.vslm.InfrastructureObjectPolicy[]"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("deleteVStorageObject", "VslmDeleteVStorageObject_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("retrieveVStorageObject", "VslmRetrieveVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vim.vslm.VStorageObject", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjectState", "VslmRetrieveVStorageObjectState", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vim.vslm.StateInfo", "vim.vslm.StateInfo"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjectAssociations", "VslmRetrieveVStorageObjectAssociations", "vslm.version.version14", (("ids", "vim.vslm.ID[]", "vslm.version.version14", F_OPTIONAL, None),), (F_OPTIONAL, "vslm.vso.VStorageObjectAssociations[]", "vslm.vso.VStorageObjectAssociations[]"), "System.View", None), ("listVStorageObjectsForSpec", "VslmListVStorageObjectForSpec", "vslm.version.version14", (("query", "vslm.vso.VStorageObjectQuerySpec[]", "vslm.version.version14", F_OPTIONAL, None),("maxResult", "int", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vslm.vso.VStorageObjectQueryResult", "vslm.vso.VStorageObjectQueryResult"), "System.View", None), ("cloneVStorageObject", "VslmCloneVStorageObject_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("spec", "vim.vslm.CloneSpec", "vslm.version.version14", 0, None),), (0, "vslm.Task", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("relocateVStorageObject", "VslmRelocateVStorageObject_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("spec", "vim.vslm.RelocateSpec", "vslm.version.version14", 0, None),), (0, "vslm.Task", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("setVStorageObjectControlFlags", "VslmSetVStorageObjectControlFlags", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("controlFlags", "string[]", "vslm.version.version14", F_OPTIONAL, None),), (0, "void", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("clearVStorageObjectControlFlags", "VslmClearVStorageObjectControlFlags", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("controlFlags", "string[]", "vslm.version.version14", F_OPTIONAL, None),), (0, "void", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("attachTagToVStorageObject", "VslmAttachTagToVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("category", "string", "vslm.version.version14", 0, None),("tag", "string", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.Read", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("detachTagFromVStorageObject", "VslmDetachTagFromVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("category", "string", "vslm.version.version14", 0, None),("tag", "string", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.Read", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("listVStorageObjectsAttachedToTag", "VslmListVStorageObjectsAttachedToTag", "vslm.version.version14", (("category", "string", "vslm.version.version14", 0, None),("tag", "string", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vim.vslm.ID[]", "vim.vslm.ID[]"), "System.Read", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("listTagsAttachedToVStorageObject", "VslmListTagsAttachedToVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vim.vslm.TagEntry[]", "vim.vslm.TagEntry[]"), "System.Read", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("reconcileDatastoreInventory", "VslmReconcileDatastoreInventory_Task", "vslm.version.version14", (("datastore", "vim.Datastore", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("scheduleReconcileDatastoreInventory", "VslmScheduleReconcileDatastoreInventory", "vslm.version.version14", (("datastore", "vim.Datastore", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("createSnapshot", "VslmCreateSnapshot_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("description", "string", "vslm.version.version14", 0, None),), (0, "vslm.Task", "vim.vslm.ID"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("deleteSnapshot", "VslmDeleteSnapshot_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("retrieveSnapshotInfo", "VslmRetrieveSnapshotInfo", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vim.vslm.VStorageObjectSnapshotInfo", "vim.vslm.VStorageObjectSnapshotInfo"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("createDiskFromSnapshot", "VslmCreateDiskFromSnapshot_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),("name", "string", "vslm.version.version14", 0, None),("profile", "vim.vm.ProfileSpec[]", "vslm.version.version14", F_OPTIONAL, None),("crypto", "vim.encryption.CryptoSpec", "vslm.version.version14", F_OPTIONAL, None),("path", "string", "vslm.version.version14", F_OPTIONAL, None),), (0, "vslm.Task", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("revertVStorageObject", "VslmRevertVStorageObject_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("retrieveSnapshotDetails", "VslmRetrieveSnapshotDetails", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vim.vslm.VStorageObjectSnapshotDetails", "vim.vslm.VStorageObjectSnapshotDetails"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("queryChangedDiskAreas", "VslmQueryChangedDiskAreas", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),("startOffset", "long", "vslm.version.version14", 0, None),("changeId", "string", "vslm.version.version14", 0, None),), (0, "vim.VirtualMachine.DiskChangeInfo", "vim.VirtualMachine.DiskChangeInfo"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vmodl.fault.InvalidArgument", "vslm.fault.VslmFault", ]), ("queryGlobalCatalogSyncStatus", "VslmQueryGlobalCatalogSyncStatus", "vslm.version.version14", (), (F_OPTIONAL, "vslm.vso.DatastoreSyncStatus[]", "vslm.vso.DatastoreSyncStatus[]"), "System.View", None), ("queryGlobalCatalogSyncStatusForDatastore", "VslmQueryGlobalCatalogSyncStatusForDatastore", "vslm.version.version14", (("datastoreURL", "string", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vslm.vso.DatastoreSyncStatus", "vslm.vso.DatastoreSyncStatus"), "System.View", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("updateVStorageObjectMetadata", "VslmUpdateVStorageObjectMetadata_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("metadata", "vim.KeyValue[]", "vslm.version.version14", F_OPTIONAL, None),("deleteKeys", "string[]", "vslm.version.version14", F_OPTIONAL, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjectMetadata", "VslmRetrieveVStorageObjectMetadata", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", F_OPTIONAL, None),("prefix", "string", "vslm.version.version14", F_OPTIONAL, None),), (F_OPTIONAL, "vim.KeyValue[]", "vim.KeyValue[]"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjectMetadataValue", "VslmRetrieveVStorageObjectMetadataValue", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", F_OPTIONAL, None),("key", "string", "vslm.version.version14", 0, None),), (0, "string", "string"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vim.fault.KeyNotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjects", "VslmRetrieveVStorageObjects", "vslm.version.version14", (("ids", "vim.vslm.ID[]", "vslm.version.version14", F_OPTIONAL, None),), (F_OPTIONAL, "vslm.vso.VStorageObjectResult[]", "vslm.vso.VStorageObjectResult[]"), "System.View", None), ("attachDisk", "VslmAttachDisk_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("vm", "vim.VirtualMachine", "vslm.version.version14", 0, None),("controllerKey", "int", "vslm.version.version14", F_OPTIONAL, None),("unitNumber", "int", "vslm.version.version14", F_OPTIONAL, None),), (0, "vslm.Task", "void"), "VirtualMachine.Config.AddExistingDisk", ["vim.fault.NotFound", "vim.fault.VmConfigFault", "vim.fault.FileFault", "vim.fault.InvalidState", "vim.fault.InvalidDatastore", "vim.fault.InvalidController", "vim.fault.MissingController", "vim.fault.DeviceUnsupportedForVmVersion", "vslm.fault.VslmFault", ])])
CreateDataType("vslm.vso.VStorageObjectQueryResult", "VslmVsoVStorageObjectQueryResult", "vmodl.DynamicData", "vslm.version.version14", [("allRecordsReturned", "boolean", "vslm.version.version14", 0), ("id", "vim.vslm.ID[]", "vslm.version.version14", F_OPTIONAL), ("queryResults", "vslm.vso.VStorageObjectResult[]", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.VStorageObjectQuerySpec", "VslmVsoVStorageObjectQuerySpec", "vmodl.DynamicData", "vslm.version.version14", [("queryField", "string", "vslm.version.version14", 0), ("queryOperator", "string", "vslm.version.version14", 0), ("queryValue", "string[]", "vslm.version.version14", F_OPTIONAL)])
CreateEnumType("vslm.vso.VStorageObjectQuerySpec.QueryOperatorEnum", "VslmVsoVStorageObjectQuerySpecQueryOperatorEnum", "vslm.version.version14", ["equals", "notEquals", "lessThan", "greaterThan", "lessThanOrEqual", "greaterThanOrEqual", "contains", "startsWith", "endsWith"])
CreateEnumType("vslm.vso.VStorageObjectQuerySpec.QueryFieldEnum", "VslmVsoVStorageObjectQuerySpecQueryFieldEnum", "vslm.version.version14", ["id", "name", "capacity", "createTime", "backingObjectId", "datastoreMoId", "metadataKey", "metadataValue"])
CreateDataType("vslm.vso.VStorageObjectResult", "VslmVsoVStorageObjectResult", "vmodl.DynamicData", "vslm.version.version14", [("id", "vim.vslm.ID", "vslm.version.version14", 0), ("name", "string", "vslm.version.version14", F_OPTIONAL), ("capacityInMB", "long", "vslm.version.version14", 0), ("createTime", "vmodl.DateTime", "vslm.version.version14", F_OPTIONAL), ("datastoreUrl", "string", "vslm.version.version14", F_OPTIONAL), ("diskPath", "string", "vslm.version.v7_0_1_0", F_OPTIONAL), ("usedCapacityInMB", "long", "vslm.version.v7_0_1_0", F_OPTIONAL), ("backingObjectId", "vim.vslm.ID", "vslm.version.version15", F_OPTIONAL), ("snapshotInfo", "vslm.vso.VStorageObjectSnapshotResult[]", "vslm.version.version15", F_OPTIONAL), ("metadata", "vim.KeyValue[]", "vslm.version.version14", F_OPTIONAL), ("error", "vmodl.MethodFault", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.VStorageObjectSnapshotResult", "VslmVsoVStorageObjectSnapshotResult", "vmodl.DynamicData", "vslm.version.version15", [("backingObjectId", "vim.vslm.ID", "vslm.version.version15", 0), ("description", "string", "vslm.version.v7_0_2_0", F_OPTIONAL), ("snapshotId", "vim.vslm.ID", "vslm.version.v7_0_2_0", F_OPTIONAL), ("diskPath", "string", "vslm.version.v7_0_2_0", F_OPTIONAL)])
CreateDataType("vslm.fault.SyncFault", "VslmSyncFault", "vslm.fault.VslmFault", "vslm.version.version14", [("id", "vim.vslm.ID", "vslm.version.v7_0", F_OPTIONAL)])
